<?xml version="1.0" encoding="utf-8"?>
<!-- conversion from xhtml to xsl-fo, hk 2004/05/22 -->
<xsl:stylesheet 
   xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
   xmlns:fo="http://www.w3.org/1999/XSL/Format"
   xmlns:html="http://www.w3.org/1999/xhtml"
   version="1.0" >

  <xsl:template match="html:body">
      <xsl:apply-templates />
  </xsl:template>

  <!-- block elements -->

  <xsl:template match="html:p">
    <fo:block space-before="8pt" space-after="4pt">
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:p[@align='center']">
    <fo:block space-before="8pt" space-after="4pt" 
              text-align="center" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:p[@align='right']">
    <fo:block space-before="8pt" space-after="4pt" 
              text-align="right" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:li/html:p">
    <fo:block space-after="4pt">
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:h1" >
    <fo:block space-before="4pt" space-after="1pt"
              break-before="page"
              font-weight="bold" 
              font-size="18pt" color="#C00" >
       <xsl:apply-templates />
    </fo:block>
    <fo:block font-size="18pt" 
              font-family="sans-serif" 
              line-height="24pt"
              space-after.optimum="5pt"
              background-color="silver"
              color="white">
       <fo:marker marker-class-name="kopf" >
         <xsl:apply-templates />
       </fo:marker>
    </fo:block>
  </xsl:template>

  <xsl:template match="html:h2">
    <fo:block space-before="4pt" space-after="1pt"
              font-weight="bold" 
              font-size="16pt" color="#C00" >
      <xsl:apply-templates  />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:h3">
    <fo:block space-before="4pt" space-after="1pt"
              font-weight="bold" 
              font-size="14pt" color="#C00" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:h4">
    <fo:block space-before="4pt" space-after="1pt"
              font-weight="bold" 
              font-size="12pt" color="#C00" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:hr">
    <fo:block space-before="8pt" space-after="8pt"
              border="1px"
              width="50%"
              border-style="inset" />
  </xsl:template>

  <xsl:template match="html:pre">
    <fo:block font-family="monospace" space-before="4pt" space-after="4pt"
              background-color="#cfcfcf" 
              white-space-collapse="false"
              wrap-option="no-wrap"
              start-indent="0.4cm"
              text-align="left" 
              ><xsl:apply-templates />
    </fo:block>
  </xsl:template>


  <!-- inline elements -->

  <xsl:template match="html:address">
    <fo:block space-before="4pt" space-after="4pt" 
              font-style="italic" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:a">
    <fo:basic-link 
        color="blue"
        external-destination="url('{@href}')" >
      <xsl:apply-templates />
    </fo:basic-link>
  </xsl:template>

  <xsl:template match="html:img">
    <fo:external-graphic src="url('{@src}')" >
    </fo:external-graphic>
  </xsl:template>

  <xsl:template match="html:br">
    <fo:block />
  </xsl:template>

  <xsl:template match="html:code">
    <fo:inline font-family="monospace" 
              white-space-collapse="false" >
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="html:em">
    <fo:inline font-style="italic" >
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>

  <xsl:template match="html:strong">
    <fo:inline font-weight="bold" >
      <xsl:apply-templates />
    </fo:inline>
  </xsl:template>


  <!-- lists elements -->

  <xsl:template match="html:ul">
    <fo:list-block space-before="8pt" space-after="2pt" >
      <xsl:apply-templates select="html:li" />
    </fo:list-block>
  </xsl:template>

  <xsl:template match="html:ul/html:li">
    <fo:list-item space-before="1pt" space-after="1pt" >
      <fo:list-item-label start-indent="0.1cm" >
        <fo:block>&#x2022;</fo:block>
      </fo:list-item-label>
      <fo:list-item-body  start-indent="body-start()" >
        <fo:block space-after="3pt" >
         <xsl:apply-templates  />
        </fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <xsl:template match="html:ol">
    <fo:list-block space-before="8pt" space-after="2pt" >
      <xsl:apply-templates select="html:li" />
    </fo:list-block>
  </xsl:template>

  <xsl:template match="html:ol/html:li">
    <fo:list-item space-before="1pt" space-after="1pt" >
      <fo:list-item-label start-indent="0.1cm" >
        <fo:block>      
           <xsl:number format="1." />
        </fo:block>
      </fo:list-item-label>
      <fo:list-item-body  start-indent="body-start()" >
        <fo:block space-after="3pt" >
         <xsl:apply-templates  />
        </fo:block>
      </fo:list-item-body>
    </fo:list-item>
  </xsl:template>

  <xsl:template match="html:dl">
    <fo:block space-before="8pt" space-after="3pt"
              >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:dt">
    <fo:block space-before="3pt" space-after="1pt"
              font-weight="bold" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <xsl:template match="html:dd">
    <fo:block space-before="1pt" space-after="1pt" 
              start-indent="0.5cm" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>


  <!-- table elements -->

  <xsl:template match="html:table">
      <fo:table border-width="1px"
                border-style="solid" 
                background-color="aqua"
                text-align="left" 
                table-layout="fixed" >
         <fo:table-column column-width="5cm"/>
         <fo:table-column column-width="5cm"/>
         <fo:table-column column-width="5cm"/>
        <fo:table-body padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
          <!--xsl:apply-templates select=".//html:tr" /-->
          <xsl:apply-templates select="html:tr" />
        </fo:table-body>
      </fo:table>
  </xsl:template>
  
  <xsl:template match="html:tr">
    <fo:table-row padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" >
       <xsl:apply-templates select="html:th|html:td"/>
    </fo:table-row>
  </xsl:template>
  
  <xsl:template match="html:th">
    <fo:table-cell font-weight="bold"
        text-align="center" 
        border-width="1px"
        border-style="solid" >
      <fo:block>         
          <xsl:apply-templates />
      </fo:block>
    </fo:table-cell>
  </xsl:template>
  
  <xsl:template match="html:td">
    <fo:table-cell border-width="1px"
        border-style="solid" >
      <fo:block padding-left="2pt"
          padding-right="2pt"
          padding-top="2pt"
          padding-bottom="2pt" 
          > 
      <xsl:apply-templates />
      </fo:block>
    </fo:table-cell>
  </xsl:template>
  
 
  <!-- form elements -->

  <xsl:template match="html:form">
    <fo:block space-before="8pt" space-after="4pt" >
      <xsl:apply-templates />
    </fo:block>
  </xsl:template>

  <!-- border do not work with fop 0.20.5 -->

  <xsl:template match="html:input[@type='button']">
    <fo:inline font-family="monospace" 
               background-color="silver"
               font-weight="bold"
               color="red"
               border="1px"
               border-style="inset"
               border-width="1px"
               border-top-width="1px"
               border-bottom-width="1px"
               border-left-width="1px"
               border-right-width="1px" 
               >
         Button: <xsl:value-of select="@value" />
    </fo:inline>
  </xsl:template>

  <xsl:template match="html:input[@type='text']">
    <fo:inline font-family="monospace" 
               background-color="silver"
               font-weight="bold"
               color="blue"
               border="1px"
               border-style="inset"
               border-width="1px"
               border-top-width="1px"
               border-bottom-width="1px"
               border-left-width="1px"
               border-right-width="1px" 
               >
      <xsl:text>  </xsl:text>
      Textfield: <xsl:value-of select="@value" />
      <xsl:text>  </xsl:text>
    </fo:inline>
  </xsl:template>

</xsl:stylesheet>
